@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -35,6 +35,8 @@
 #endif /* HAVE_UNISTD_H */
 
 #include <glib.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
 #include "egg-debug.h"
 #include "egg-idletime.h"
@@ -48,7 +50,6 @@
 /* Sets the idle percent limit, i.e. how hard the computer can work
    while considered "at idle" */
 #define GPM_IDLE_CPU_LIMIT			5
-#define GPM_IDLE_TIMEOUT_IGNORE_DPMS_CHANGE	1.0f /* seconds */
 #define	GPM_IDLE_IDLETIME_ID			1
 
 struct GpmIdlePrivate
@@ -64,7 +65,6 @@ struct GpmIdlePrivate
 	guint		 timeout_sleep_id;
 	gboolean	 x_idle;
 	gboolean	 check_type_cpu;
-	GTimer		*timer;
 };
 
 enum {
@@ -105,11 +105,6 @@ gpm_idle_set_mode (GpmIdle *idle, GpmIdleMode mode)
 
 	if (mode != idle->priv->mode) {
 		idle->priv->mode = mode;
-
-		/* we save the time of the last state, so we can ignore the X11
-		 * timer reset when we change brightness or do DPMS actions */
-		g_timer_reset (idle->priv->timer);
-
 		egg_debug ("Doing a state transition: %s", gpm_idle_mode_to_text (mode));
 		g_signal_emit (idle, signals [IDLE_CHANGED], 0, mode);
 	}
@@ -183,11 +178,13 @@ static void
 gpm_idle_evaluate (GpmIdle *idle)
 {
 	gboolean is_idle;
-	gboolean is_inhibited;
+	gboolean is_idle_inhibited;
+	gboolean is_suspend_inhibited;
 
 	is_idle = gpm_session_get_idle (idle->priv->session);
-	is_inhibited = gpm_session_get_inhibited (idle->priv->session);
-	egg_debug ("is_idle=%i, is_inhibited=%i", is_idle, is_inhibited);
+	is_idle_inhibited = gpm_session_get_idle_inhibited (idle->priv->session);
+	is_suspend_inhibited = gpm_session_get_suspend_inhibited (idle->priv->session);
+	egg_debug ("session_idle=%i, idle_inhibited=%i, suspend_inhibited=%i, x_idle=%i", is_idle, is_idle_inhibited, is_suspend_inhibited, idle->priv->x_idle);
 
 	/* check we are really idle */
 	if (!idle->priv->x_idle) {
@@ -204,8 +201,8 @@ gpm_idle_evaluate (GpmIdle *idle)
 		goto out;
 	}
 
-	/* are we inhibited */
-	if (is_inhibited) {
+	/* are we inhibited from going idle */
+	if (is_idle_inhibited) {
 		egg_debug ("inhibited, so using normal state");
 		gpm_idle_set_mode (idle, GPM_IDLE_MODE_NORMAL);
 		if (idle->priv->timeout_blank_id != 0) {
@@ -229,15 +226,22 @@ gpm_idle_evaluate (GpmIdle *idle)
 	 * but only if we actually want to blank. */
 	if (idle->priv->timeout_blank_id == 0 &&
 	    idle->priv->timeout_blank != 0) {
-		egg_debug ("setting up blank callback");
+		egg_debug ("setting up blank callback for %is", idle->priv->timeout_blank);
 		idle->priv->timeout_blank_id = g_timeout_add_seconds (idle->priv->timeout_blank, (GSourceFunc) gpm_idle_blank_cb, idle);
 	}
 
-	/* only do the sleep timeout when the session is idle */
-	if (is_idle) {
+	/* are we inhibited from sleeping */
+	if (is_suspend_inhibited) {
+		egg_debug ("suspend inhibited");
+		if (idle->priv->timeout_sleep_id != 0) {
+			g_source_remove (idle->priv->timeout_sleep_id);
+			idle->priv->timeout_sleep_id = 0;
+		}
+	} else if (is_idle) {
+	/* only do the sleep timeout when the session is idle and we aren't inhibited from sleeping */
 		if (idle->priv->timeout_sleep_id == 0 &&
 		    idle->priv->timeout_sleep != 0) {
-			egg_debug ("setting up sleep callback = %i", idle->priv->timeout_blank);
+			egg_debug ("setting up sleep callback %is", idle->priv->timeout_sleep);
 			idle->priv->timeout_sleep_id = g_timeout_add_seconds (idle->priv->timeout_sleep, (GSourceFunc) gpm_idle_sleep_cb, idle);
 		}
 	}
@@ -317,17 +321,9 @@ gpm_idle_session_idle_changed_cb (GpmSession *session, gboolean is_idle, GpmIdle
  * gpm_idle_session_inhibited_changed_cb:
  **/
 static void
-gpm_idle_session_inhibited_changed_cb (GpmSession *session, gboolean is_inhibited, GpmIdle *idle)
+gpm_idle_session_inhibited_changed_cb (GpmSession *session, gboolean is_idle_inhibited, gboolean is_suspend_inhibited, GpmIdle *idle)
 {
-	egg_debug ("Received gnome session inhibited changed: %i", is_inhibited);
-
-	/* gnome-session IDLETIME bug -- For more details see:
-	 * http://blogs.gnome.org/hughsie/2009/07/30/accidental-blanking-and-gnome-power-manager/ */
-	if (!is_inhibited) {
-		egg_warning ("performing gnome-session IDLETIME bodge");
-		egg_idletime_alarm_reset_all (idle->priv->idletime);
-	}
-
+	egg_debug ("Received gnome session inhibited changed: idle=(%i), suspend=(%i)", is_idle_inhibited, is_suspend_inhibited);
 	gpm_idle_evaluate (idle);
 }
 
@@ -339,10 +335,7 @@ gpm_idle_session_inhibited_changed_cb (GpmSession *session, gboolean is_inhibite
 static void
 gpm_idle_idletime_alarm_expired_cb (EggIdletime *idletime, guint alarm_id, GpmIdle *idle)
 {
-	egg_warning ("idletime alarm: %i", alarm_id);
-
-	/* reset time to dim default (could be 1ms) */
-	egg_idletime_alarm_set (idle->priv->idletime, GPM_IDLE_IDLETIME_ID, idle->priv->timeout_dim * 1000);
+	egg_debug ("idletime alarm: %i", alarm_id);
 
 	/* set again */
 	idle->priv->x_idle = TRUE;
@@ -357,19 +350,7 @@ gpm_idle_idletime_alarm_expired_cb (EggIdletime *idletime, guint alarm_id, GpmId
 static void
 gpm_idle_idletime_reset_cb (EggIdletime *idletime, GpmIdle *idle)
 {
-	gdouble elapsed;
-	elapsed = g_timer_elapsed (idle->priv->timer, NULL);
-
-	egg_warning ("idletime reset");
-
-	/* have we just chaged state? */
-	if (idle->priv->mode == GPM_IDLE_MODE_BLANK &&
-	    elapsed < GPM_IDLE_TIMEOUT_IGNORE_DPMS_CHANGE) {
-		egg_debug ("ignoring reset, as we've just done a state change");
-		/* make sure we trigger a short 1ms timeout so we can get the expired signal */
-		egg_idletime_alarm_set (idle->priv->idletime, GPM_IDLE_IDLETIME_ID, 1);
-		return;
-	}
+	egg_debug ("idletime reset");
 
 	idle->priv->x_idle = FALSE;
 	gpm_idle_evaluate (idle);
@@ -396,7 +377,6 @@ gpm_idle_finalize (GObject *object)
 	if (idle->priv->timeout_sleep_id != 0)
 		g_source_remove (idle->priv->timeout_sleep_id);
 
-	g_timer_destroy (idle->priv->timer);
 	g_object_unref (idle->priv->load);
 	g_object_unref (idle->priv->session);
 
@@ -446,7 +426,6 @@ gpm_idle_init (GpmIdle *idle)
 	idle->priv->timeout_blank_id = 0;
 	idle->priv->timeout_sleep_id = 0;
 	idle->priv->x_idle = FALSE;
-	idle->priv->timer = g_timer_new ();
 	idle->priv->load = gpm_load_new ();
 	idle->priv->session = gpm_session_new ();
 	g_signal_connect (idle->priv->session, "idle-changed", G_CALLBACK (gpm_idle_session_idle_changed_cb), idle);
